@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-"""Testing the code for the OMS detection"""
+"""Testing the code for the OMS detection."""
 import pytest
 
 from mofchecker import MOFChecker
@@ -7,7 +7,7 @@ from mofchecker import MOFChecker
 
 @pytest.mark.skip
 def test_has_oms(get_cn4_structure, get_cn5_paddlewheel_structure):
-    """Test two specific structures"""
+    """Test two specific structures."""
     omsdetector = MOFChecker(get_cn4_structure)
     assert omsdetector.has_oms
 
@@ -17,7 +17,7 @@ def test_has_oms(get_cn4_structure, get_cn5_paddlewheel_structure):
 
 @pytest.mark.skip
 def test_has_oms_multiple(get_testdict):
-    """Test on a bunch of different structures"""
+    """Test on a bunch of different structures."""
     for key, value in get_testdict.items():
         omsdetector = MOFChecker.from_cif(key)
         assert omsdetector.has_oms == value
